@@ -1,4 +1,4 @@
-## last modified 19 November 04 by J. Fox
+## last modified 3 September 05 by J. Fox
 
 effect <- function(term, mod, ...){
     UseMethod("effect", mod)
@@ -362,7 +362,7 @@ summary.effect.list <- function(object, ...){
     invisible(NULL) 
     }
         
-as.data.frame.effect <- function(x, row.names=NULL, optional=TRUE){
+as.data.frame.effect <- function(x, row.names=NULL, optional=TRUE, ...){
     if (is.null(x$se)) data.frame(x$x, fit=x$fit)
     else data.frame(x$x, fit=x$fit, se=x$se, lower=x$lower, upper=x$upper)
     }
